@@ -1,9 +1,9 @@
 #ifndef _GIOMM_H
 #define _GIOMM_H
 
-/* 
+/*
  * Copyright (C) 2007 The giomm Development Team
- * 
+ *
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -34,10 +34,16 @@
 #include <giomm/dbusaddress.h>
 #include <giomm/dbusauthobserver.h>
 #include <giomm/dbusconnection.h>
+#include <giomm/dbuserror.h>
+#include <giomm/dbuserrorutils.h>
+#include <giomm/dbusintrospection.h>
 #include <giomm/dbusmessage.h>
 #include <giomm/dbusmethodinvocation.h>
 #include <giomm/dbusownname.h>
+#include <giomm/dbusproxy.h>
 #include <giomm/dbusserver.h>
+#include <giomm/dbusutils.h>
+#include <giomm/dbuswatchname.h>
 #ifndef G_OS_WIN32
 # include <giomm/desktopappinfo.h>
 #endif
@@ -102,4 +108,3 @@
 #include <giomm/volumemonitor.h>
 
 #endif /* #ifndef _GIOMM_H */
-
